@@ -14,10 +14,10 @@ License: GNU General Public License (GNU GPL) v. 2
 void WofostModel::soil_initialize() {
 	ROOTD_initialize();
 	if (control.water_limited) {
-		if (soil.p.IZT == 0) {
-			WATFD_initialize();
-		} else {
+		if (soil.p.IZT) {
 			WATGW_initialize();
+		} else {
+			WATFD_initialize();
 		}
 	} else {
 		WATPP_initialize();
@@ -28,10 +28,10 @@ void WofostModel::soil_initialize() {
 void WofostModel::soil_rates() {
 
 	if (control.water_limited) {
-		if (soil.p.IZT == 0) {
-			WATFD_rates();
-		} else {
+		if (soil.p.IZT) {
 			WATGW_rates();
+		} else {
+			WATFD_rates();
 		}
 	} else {
 		WATPP_rates();
@@ -40,12 +40,13 @@ void WofostModel::soil_rates() {
 
 void WofostModel::soil_states() {
 	if (control.water_limited) {
-		if (soil.p.IZT == 0) {
-			WATFD_states();
-		} else {
+		if (soil.p.IZT) {
 			WATGW_states();
+		} else {
+			WATFD_states();
 		}
 	} else {
 		WATPP_states();
 	}
 }
+
